# Docassemble Default and Inverted Navbar

# Buttons

Checkbox 1 Checkbox 2 Checkbox 3
Radio 1 Radio 2 Radio 3

# Typography

# Heading 1

## Heading 2

### Heading 3

#### Heading 4

##### Heading 5

###### Heading 6

### Heading with faded secondary text

Vivamus sagittis lacus vel augue laoreet rutrum faucibus dolor auctor.

## Example body text

Nullam quis risus eget urna mollis ornare vel eu leo. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Nullam id dolor id nibh ultricies vehicula.

This line of text is meant to be treated as fine print.

The following is rendered as bold text.

The following is rendered as italicized text.

An abbreviation of the word attribute is attr.

## Emphasis classes

.text-primary

.text-primary-emphasis

.text-secondary

.text-secondary-emphasis

.text-success

.text-success-emphasis

.text-danger

.text-danger-emphasis

.text-warning

.text-warning-emphasis

.text-info

.text-info-emphasis

.text-light

.text-light-emphasis

.text-dark

.text-dark-emphasis

.text-body

.text-body-emphasis

.text-body-secondary

.text-body-tertiary

## Blockquotes

> Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer posuere erat a ante.

Someone famous in Source Title

> Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer posuere erat a ante.

Someone famous in Source Title

> Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer posuere erat a ante.

Someone famous in Source Title

# Tables

Type | Column heading | Column heading | Column heading
--- | --- | --- | ---
Active | Column content | Column content | Column content
Default | Column content | Column content | Column content
Primary | Column content | Column content | Column content
Secondary | Column content | Column content | Column content
Success | Column content | Column content | Column content
Danger | Column content | Column content | Column content
Warning | Column content | Column content | Column content
Info | Column content | Column content | Column content
Light | Column content | Column content | Column content
Dark | Column content | Column content | Column content

# Forms

Legend
Email
Email address We'll never share your email with anyone else.
Password
Example select
Example disabled select
Example multiple select
Example textarea
Default file input example
Radio buttons
Option one is this and that—be sure to include why it's great
Option two can be something else and selecting it will deselect option one
Option three is disabled
Checkboxes
Default checkbox
Checked checkbox
Switches
Default switch checkbox input
Checked switch checkbox input
Ranges Example range Disabled range Example range
Disabled input
Readonly input
Valid input
Success! You've done it.
Invalid input
Sorry, that username's taken. Try another?
Large input
Default input
Small input
Input addons
$ .00
Floating labels
Email address
Password

# Navs

## Tabs

Raw denim you probably haven't heard of them jean shorts Austin. Nesciunt tofu stumptown aliqua, retro synth master cleanse. Mustache cliche tempor, williamsburg carles vegan helvetica. Reprehenderit butcher retro keffiyeh dreamcatcher synth. Cosby sweater eu banh mi, qui irure terry richardson ex squid. Aliquip placeat salvia cillum iphone. Seitan aliquip quis cardigan american apparel, butcher voluptate nisi qui.

Food truck fixie locavore, accusamus mcsweeney's marfa nulla single-origin coffee squid. Exercitation +1 labore velit, blog sartorial PBR leggings next level wes anderson artisan four loko farm-to-table craft beer twee. Qui photo booth letterpress, commodo enim craft beer mlkshk aliquip jean shorts ullamco ad vinyl cillum PBR. Homo nostrud organic, assumenda labore aesthetic magna delectus mollit.

Etsy mixtape wayfarers, ethical wes anderson tofu before they sold out mcsweeney's organic lomo retro fanny pack lo-fi farm-to-table readymade. Messenger bag gentrify pitchfork tattooed craft beer, iphone skateboard locavore carles etsy salvia banksy hoodie helvetica. DIY synth PBR banksy irony. Leggings gentrify squid 8-bit cred pitchfork.

Trust fund seitan letterpress, keytar raw denim keffiyeh etsy art party before they sold out master cleanse gluten-free squid scenester freegan cosby sweater. Fanny pack portland seitan DIY, art party locavore wolf cliche high life echo park Austin. Cred vinyl keffiyeh DIY salvia PBR, banh mi before they sold out farm-to-table VHS viral locavore cosby sweater.

## Pills

## Breadcrumbs

## Pagination

- «
- 1
- 2
- 3
- 4
- 5
- »

- «
- 1
- 2
- 3
- 4
- 5
- »

- «
- 1
- 2
- 3
- 4
- 5
- »

# Indicators

## Alerts

#### Warning!

Best check yo self, you're not looking too good. Nulla vitae elit libero, a pharetra augue. Praesent commodo cursus magna, vel scelerisque nisl consectetur et.

Oh snap! Change a few things up and try submitting again.
Well done! You successfully read this important alert message.
Heads up! This alert needs your attention, but it's not super important.
Oh snap! Change a few things up and try submitting again.
Well done! You successfully read this important alert message.
Heads up! This alert needs your attention, but it's not super important.

## Badges

Primary Secondary Success Danger Warning Info Light Dark
Primary Secondary Success Danger Warning Info Light Dark

# Progress

### Basic

### Contextual alternatives

### Multiple bars

### Striped

### Animated

# Containers

## List groups

- Cras justo odio 14
- Dapibus ac facilisis in 2
- Morbi leo risus 1

- Cras justo odio 14
- Dapibus ac facilisis in 2
- Morbi leo risus 1
- Cras justo odio 5
- Dapibus ac facilisis in 4
- Morbi leo risus 9
- Morbi leo risus 8
- Morbi leo risus 0

Cras justo odio Dapibus ac facilisis in Morbi leo risus

##### List group item heading

3 days ago

Donec id elit non mi porta gravida at eget metus. Maecenas sed diam eget risus varius blandit.

Donec id elit non mi porta.

##### List group item heading

3 days ago

Donec id elit non mi porta gravida at eget metus. Maecenas sed diam eget risus varius blandit.

Donec id elit non mi porta.

## Cards

Header

#### Primary card title

Some quick example text to build on the card title and make up the bulk of the card's content.

Header

#### Secondary card title

Some quick example text to build on the card title and make up the bulk of the card's content.

Header

#### Success card title

Some quick example text to build on the card title and make up the bulk of the card's content.

Header

#### Danger card title

Some quick example text to build on the card title and make up the bulk of the card's content.

Header

#### Warning card title

Some quick example text to build on the card title and make up the bulk of the card's content.

Header

#### Info card title

Some quick example text to build on the card title and make up the bulk of the card's content.

Header

#### Light card title

Some quick example text to build on the card title and make up the bulk of the card's content.

Header

#### Dark card title

Some quick example text to build on the card title and make up the bulk of the card's content.

Header

#### Primary card title

Some quick example text to build on the card title and make up the bulk of the card's content.

Header

#### Secondary card title

Some quick example text to build on the card title and make up the bulk of the card's content.

Header

#### Success card title

Some quick example text to build on the card title and make up the bulk of the card's content.

Header

#### Danger card title

Some quick example text to build on the card title and make up the bulk of the card's content.

Header

#### Warning card title

Some quick example text to build on the card title and make up the bulk of the card's content.

Header

#### Info card title

Some quick example text to build on the card title and make up the bulk of the card's content.

Header

#### Light card title

Some quick example text to build on the card title and make up the bulk of the card's content.

Header

#### Dark card title

Some quick example text to build on the card title and make up the bulk of the card's content.

### Card header

##### Special title treatment

###### Support card subtitle

Some quick example text to build on the card title and make up the bulk of the card's content.

- Cras justo odio
- Dapibus ac facilisis in
- Vestibulum at eros

Card link Another link

#### Card title

###### Card subtitle

Some quick example text to build on the card title and make up the bulk of the card's content.

Card link Another link

## Accordions

##

This is the first item's accordion body. It is shown by default, until the collapse plugin adds the appropriate classes that we use to style each element. These classes control the overall appearance, as well as the showing and hiding via CSS transitions. You can modify any of this with custom CSS or overriding our default variables. It's also worth noting that just about any HTML can go within the `.accordion-body`, though the transition does limit overflow.

##

This is the second item's accordion body. It is hidden by default, until the collapse plugin adds the appropriate classes that we use to style each element. These classes control the overall appearance, as well as the showing and hiding via CSS transitions. You can modify any of this with custom CSS or overriding our default variables. It's also worth noting that just about any HTML can go within the `.accordion-body`, though the transition does limit overflow.

##

This is the third item's accordion body. It is hidden by default, until the collapse plugin adds the appropriate classes that we use to style each element. These classes control the overall appearance, as well as the showing and hiding via CSS transitions. You can modify any of this with custom CSS or overriding our default variables. It's also worth noting that just about any HTML can go within the `.accordion-body`, though the transition does limit overflow.

# Dialogs

## Modals

##### Modal title

Modal body text goes here.

## Offcanvas

Link with href

##### Offcanvas

Some text as placeholder. In real life you can have the elements you have chosen. Like, text, images, lists, etc.

## Popovers

## Tooltips

## Toasts

Bootstrap 11 mins ago
Hello, world! This is a toast message.